@@ -10,8 +10,8 @@
 
 #include <KeySequenceRecorder>
 
-#include <QQuickItem>
 #include <QKeySequence>
+#include <QQuickItem>
 
 class KeySequenceHelperPrivate;
 class QQuickWindow;
@@ -21,43 +21,41 @@ class KeySequenceHelper : public KeySequenceRecorder
     Q_OBJECT
 
     Q_PROPERTY(
-        ShortcutTypes checkAgainstShortcutTypes
-        READ checkAgainstShortcutTypes
-        WRITE setCheckAgainstShortcutTypes
-        NOTIFY checkAgainstShortcutTypesChanged
-    )
+        ShortcutTypes checkAgainstShortcutTypes READ checkAgainstShortcutTypes WRITE setCheckAgainstShortcutTypes NOTIFY checkAgainstShortcutTypesChanged)
 
 public:
-
     enum ShortcutType {
-        None           = 0x00,      //!< No checking for conflicts
-        StandardShortcuts = 0x01,   //!< Check against standard shortcuts. @see KStandardShortcut
-        GlobalShortcuts = 0x02      //!< Check against global shortcuts. @see KGlobalAccel
+        None = 0x00, //!< No checking for conflicts
+        StandardShortcuts = 0x01, //!< Check against standard shortcuts. @see KStandardShortcut
+        GlobalShortcuts = 0x02, //!< Check against global shortcuts. @see KGlobalAccel
     };
     Q_DECLARE_FLAGS(ShortcutTypes, ShortcutType)
     Q_FLAG(ShortcutTypes)
 
     /**
-    * Constructor.
-    */
+     * Constructor.
+     */
     explicit KeySequenceHelper(QObject *parent = nullptr);
 
     /**
-    * Destructs the widget.
-    */
-    virtual ~KeySequenceHelper();
+     * Destructs the widget.
+     */
+    ~KeySequenceHelper() override;
 
     Q_INVOKABLE bool isKeySequenceAvailable(const QKeySequence &keySequence) const;
     // FIXME why can't qml call the inherited method?
-    Q_INVOKABLE void startRecording() {KeySequenceRecorder::startRecording();}
+    Q_INVOKABLE void startRecording()
+    {
+        KeySequenceRecorder::startRecording();
+    }
 
     ShortcutTypes checkAgainstShortcutTypes();
     void setCheckAgainstShortcutTypes(ShortcutTypes types);
 
+    Q_INVOKABLE static QKeySequence fromString(const QString &str = QString());
     Q_INVOKABLE static bool keySequenceIsEmpty(const QKeySequence &keySequence);
     Q_INVOKABLE static QString keySequenceNativeText(const QKeySequence &keySequence);
-    Q_INVOKABLE static QWindow* renderWindow(QQuickWindow *quickWindow);
-
+    Q_INVOKABLE static QWindow *renderWindow(QQuickWindow *quickWindow);
 
 Q_SIGNALS:
     void checkAgainstShortcutTypesChanged();
@@ -71,5 +69,4 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KeySequenceHelper::ShortcutTypes)
 
-
 #endif // KEYSEQUENCEHELPER_H
