@@ -115,7 +115,7 @@ void PlotData::addSample(qreal value)
 
     m_max = std::numeric_limits<qreal>::min();
     m_min = std::numeric_limits<qreal>::max();
-    for (auto v : qAsConst(m_values)) {
+    for (auto v : std::as_const(m_values)) {
         if (v > m_max) {
             m_max = v;
         } else if (v < m_min) {
@@ -278,7 +278,8 @@ public:
     {
         m_program->setUniformValue(u_yMax, max);
     }
-    ~PlotSGNode() = default;
+    ~PlotSGNode() override = default;
+
 private:
     QScopedPointer<QOpenGLShaderProgram> m_program;
     int u_matrix;
@@ -356,7 +357,7 @@ void Plotter::setSampleSize(int size)
     m_sampleSize = size;
 
     m_mutex.lock();
-    for (auto data : qAsConst(m_plotData)) {
+    for (auto data : std::as_const(m_plotData)) {
         data->setSampleSize(size);
     }
     m_mutex.unlock();
@@ -494,7 +495,7 @@ void Plotter::addSample(const QList<qreal> &value)
 
     int i = 0;
     m_mutex.lock();
-    for (auto data : qAsConst(m_plotData)) {
+    for (auto data : std::as_const(m_plotData)) {
         data->addSample(value.value(i));
         ++i;
     }
@@ -514,13 +515,21 @@ void Plotter::dataSet_append(QQmlListProperty<PlotData> *list, PlotData *item)
     p->m_mutex.unlock();
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 int Plotter::dataSet_count(QQmlListProperty<PlotData> *list)
+#else
+qsizetype Plotter::dataSet_count(QQmlListProperty<PlotData> *list)
+#endif
 {
     Plotter *p = static_cast<Plotter *>(list->object);
     return p->m_plotData.count();
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 PlotData *Plotter::dataSet_at(QQmlListProperty<PlotData> *list, int index)
+#else
+PlotData *Plotter::dataSet_at(QQmlListProperty<PlotData> *list, qsizetype index)
+#endif
 {
     Plotter *p = static_cast<Plotter *>(list->object);
     p->m_mutex.lock();
@@ -632,7 +641,7 @@ void Plotter::render()
     int roundedHeight = qRound(height());
     int roundedWidth = qRound(width());
 
-    for (auto data : qAsConst(m_plotData)) {
+    for (auto data : std::as_const(m_plotData)) {
         // Interpolate the data set
         const QPainterPath path = interpolate(data->m_normalizedValues, 0, roundedWidth);
 
@@ -705,7 +714,7 @@ void Plotter::render()
 
     QPair<int, int> oldCount;
     m_mutex.lock();
-    for (auto data : qAsConst(m_plotData)) {
+    for (auto data : std::as_const(m_plotData)) {
         color2 = data->color();
         color2.setAlphaF(0.60);
         // Draw the graph
@@ -836,9 +845,17 @@ QSGNode *Plotter::updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *updateP
     return n;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void Plotter::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
+#else
+void Plotter::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
+#endif
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QQuickItem::geometryChanged(newGeometry, oldGeometry);
+#else
+    QQuickItem::geometryChange(newGeometry, oldGeometry);
+#endif
     normalizeData();
 }
 
@@ -893,7 +910,7 @@ void Plotter::normalizeData()
         } while (i != m_plotData.constBegin());
 
     } else {
-        for (auto data : qAsConst(m_plotData)) {
+        for (auto data : std::as_const(m_plotData)) {
             data->m_normalizedValues.clear();
             data->m_normalizedValues = data->values().toVector();
             // global max and global min
@@ -907,11 +924,13 @@ void Plotter::normalizeData()
     }
     m_mutex.unlock();
 
-    if (adjustedMin > 0.0 && adjustedMax > 0.0)
+    if (adjustedMin > 0.0 && adjustedMax > 0.0) {
         adjustedMin = 0.0;
+    }
 
-    if (adjustedMin < 0.0 && adjustedMax < 0.0)
+    if (adjustedMin < 0.0 && adjustedMax < 0.0) {
         adjustedMax = 0.0;
+    }
 
     if (m_autoRange || m_rangeMax > m_rangeMin) {
         if (!m_autoRange) {
@@ -929,7 +948,7 @@ void Plotter::normalizeData()
 
         // normalizebased on global max and min
         m_mutex.lock();
-        for (auto data : qAsConst(m_plotData)) {
+        for (auto data : std::as_const(m_plotData)) {
             for (int i = 0; i < data->values().count(); ++i) {
                 data->m_normalizedValues[i] = (data->m_normalizedValues.value(i) - adjustedMin) * adjust;
             }
